summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/flt_rc.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/flt_rc.h')
-rw-r--r--src/devices/sound/flt_rc.h18
1 files changed, 7 insertions, 11 deletions
diff --git a/src/devices/sound/flt_rc.h b/src/devices/sound/flt_rc.h
index 3b9748afaaf..8e6057ceed0 100644
--- a/src/devices/sound/flt_rc.h
+++ b/src/devices/sound/flt_rc.h
@@ -33,24 +33,15 @@
* Same as FLT_RC_HIGHPASS, but with standard frequency of 16 HZ
* This filter may be setup just with
*
- * MCFG_FILTER_RC_ADD("tag", 0)
- * MCFG_FILTER_RC_AC()
+ * FILTER_RC(config, "tag", 0).set_ac();
*
* Default behaviour:
*
* Without MCFG_FILTER_RC_AC, a disabled FLT_RC_LOWPASS is created
*
*/
//**************************************************************************
-// INTERFACE CONFIGURATION MACROS
-//**************************************************************************
-
-#define MCFG_FILTER_RC_AC() \
- downcast<filter_rc_device &>(*device).set_rc(filter_rc_device::AC, 10000, 0, 0, CAP_U(1));
-
-
-//**************************************************************************
// TYPE DEFINITIONS
//**************************************************************************
@@ -87,6 +78,11 @@ public:
return *this;
}
+ filter_rc_device &set_ac()
+ {
+ return set_rc(filter_rc_device::AC, 10000, 0, 0, CAP_U(1));
+ }
+
protected:
// device-level overrides
virtual void device_start() override;
@@ -33,24 +33,15 @@
* Default behaviour:
*
- * Without MCFG_FILTER_RC_AC, a disabled FLT_RC_LOWPASS is created
+ * Without set_ac(), a disabled FLT_RC_LOWPASS is created
*
*/